==> semantic_kernel-1.26.1.tar.gz: semantic_kernel-1.26.1/semantic_kernel/connectors/ai/bedrock/services/bedrock_base.py <==
# Copyright (c) Microsoft. All rights reserved.

from abc import ABC
from functools import partial
from typing import Any, ClassVar

import boto3

from semantic_kernel.kernel_pydantic import KernelBaseModel
from semantic_kernel.utils.async_utils import run_in_executor


class BedrockBase(KernelBaseModel, ABC):
    """Amazon Bedrock Service Base Class."""

    MODEL_PROVIDER_NAME: ClassVar[str] = "bedrock"

    # Amazon Bedrock Clients
    # Runtime Client: Use for inference
    bedrock_runtime_client: Any
    # Client: Use for model management
    bedrock_client: Any

    def __init__(
        self,
        *,
        runtime_client: Any | None = None,
        client: Any | None = None,
        **kwargs: Any,
    ) -> None:
        """Initialize the Amazon Bedrock Base Class.

        Args:
            runtime_client: The Amazon Bedrock runtime client to use.
            client: The Amazon Bedrock client to use.
            **kwargs: Additional keyword arguments.
        """
        super().__init__(
            bedrock_runtime_client=runtime_client or boto3.client("bedrock-runtime"),
            bedrock_client=client or boto3.client("bedrock"),
            **kwargs,
        )

    async def get_foundation_model_info(self, model_id: str) -> dict[str, Any]:
        """Get the foundation model information."""
        response = await run_in_executor(
            None,
            partial(
                self.bedrock_client.get_foundation_model,
                modelIdentifier=model_id,
            ),
        )

        return response.get("modelDetails")

==> semantic_kernel-1.35.2.tar.gz: semantic_kernel-1.35.2/semantic_kernel/connectors/ai/bedrock/services/bedrock_base.py <==
# Copyright (c) Microsoft. All rights reserved.

from abc import ABC
from typing import Any, ClassVar

import boto3

from semantic_kernel.connectors.ai.bedrock.services.model_provider.bedrock_model_provider import BedrockModelProvider
from semantic_kernel.kernel_pydantic import KernelBaseModel


class BedrockBase(KernelBaseModel, ABC):
    """Amazon Bedrock Service Base Class."""

    MODEL_PROVIDER_NAME: ClassVar[str] = "bedrock"

    # Amazon Bedrock Clients
    # Runtime Client: Use for inference
    bedrock_runtime_client: Any
    # Client: Use for model management
    bedrock_client: Any

    bedrock_model_provider: BedrockModelProvider | None = None

    def __init__(
        self,
        *,
        runtime_client: Any | None = None,
        client: Any | None = None,
        bedrock_model_provider: BedrockModelProvider | None = None,
        **kwargs: Any,
    ) -> None:
        """Initialize the Amazon Bedrock Base Class.

        Args:
            runtime_client: The Amazon Bedrock runtime client to use.
            client: The Amazon Bedrock client to use.
            bedrock_model_provider: The Bedrock model provider to use.
                If not provided, the model provider will be extracted from the model ID.
                When using an Application Inference Profile where the model provider is not part
                of the model ID, this setting must be provided.
            **kwargs: Additional keyword arguments.
        """
        super().__init__(
            bedrock_runtime_client=runtime_client or boto3.client("bedrock-runtime"),
            bedrock_client=client or boto3.client("bedrock"),
            bedrock_model_provider=bedrock_model_provider,
            **kwargs,
        )
